package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(`*``!````D1D!`#0```"0L@````0`!30`(``)
M`"@`'``;``$``'"LH0``K*$!`*RA`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!0````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0"XH0``N*$```4```````$`
M`0```/2N``#TK@(`]*X"`#@"``"`$@``!@```````0`"`````*\```"O`@``
MKP(```$````!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D]*X`
M`/2N`@#TK@(`#`$```P!```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````,````"``````````0````4
M`````P```$=.50">A<:U%X.76/7A))KRQ`.D70:YVV$````%````(`````H`
M``"@$@`(`D01(``"0`!6`'`8P@@`,`@`$!$``!`"`"@`````````2`(@"@`*
M``2$`JA`"`5@:0"$"3Y"/)<``0`()%B`!`E@#)-X"4):`$``0``!`$()`$"`
MC,"$```0D!"#"0`(`1"`@4!`P@F`+$"8`D$`(``@!`F`D`$D#I=V0`4`````
M````!@````<````)``````````````````````````H````,````#0````\`
M```0````$0```!,````6`````````````````````````!@````;````'```
M```````@````(0```"(`````````(P```"0````H`````````"H`````````
M`````"L````L````+0```"X`````````,@```#,`````````-P``````````
M````.````#L````\`````````#T````^````0````$(```!%`````````$<`
M``!(````20```$H`````````2P``````````````````````````````````
M`$P```!-`````````$\`````````40```%,```!5````````````````````
M`````%8```!:`````````%P`````````7@````````!@````80``````````
M````8P```&0```!F````9P```&H```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1
M!(2!=((->_!*:W94/)3-/PRO]R/.((D'<-,@=+`"U634?&:OS&8N3CWVV_<`
M7@:DA_\!KS3HSDJN_\[>1RWAIP(*XT?&`<8.X#T^?I9\[#^0`FUSA<7%B060
M89CO$@$C^:2=NY,<0D75[%#N$>.&^9R!?>T1#[J5DQQ;FCL/04V=?*?=HVM9
M[Y=Y.?*+'`P4XIX$,J6%H@+V&=O-XY[[H6Q@ZM/O#L@Y0!\R8MOMN8WQ#NG[
MP\)*(GW_"HH05^W>DQRM2^/`V7%8'"O0X2(:G]:]+0ZQ<U@[0!_#Y3\LF"+4
M:+KCDGPA_^0.BIC=PF]Z:?J3K01B-^/PP4/R[\C?A2!/5Z2;EL6YG$!0&WU?
M,;B"#;[:5QNS`8MOO-!+?7=OXW!J"4/6GR+'J"%B9`=^J9R;8M#Z@NPL]HMK
M?YI\AO"6?-&?+/SN"U'Y\]O3'9!U@@U#9DL0!6RRS3RM.0T7ZEKQH^#[2>)7
MQ!A7DEI2_=+O#V[%WQ]\D!#I+=_^2"[%F[;)U;)Q````````````````````
M`!$``````````````"`````M```````````````@````/```````````````
M(````%```````````````"````!2`P`````````````2````%0(`````````
M````$@```*P"`````````````!(```"0`@`````````````2````100``!RQ
M`@``````(``7`)L!`````````````!(```")`@`````````````2````BP$`
M`#`5`0``````$@```*X#```LL0(``````!``&`!#`@`````````````2````
M;@(`````````````$@```(4$```HL0(`!````!$`%P#O`@`````````````2
M````T00``)E<`0">`@``$@`-`"H$```-4@$`J````!(`#0!9`P``````````
M```2````5`(`````````````$@`````#`````````````!(```"]`P``=,$"
M```````0`!@`"`0`````````````$@```#8$``!950$`0`<``!(`#0!?!```
MV4\!`)(````2``T`'00``/51`0`6````$@`-`'L"`````````````!(````^
M`@`````````````2````9`$`````````````$@```-P"`````````````!(`
M``!L`P``,+$"``0````A`!@`_0$`````````````$@````0"````````````
M`!(```">`@`````````````2````FP,``"RQ`@``````$``7`+D"````````
M`````!(```"'````6!<!```````2````@P(`````````````$@```"0#````
M`````````!(```#W`0`````````````2````'0(`````````````$@```&T#
M```PL0(`!````"$`&`#(`P``=,$"```````0`!@`^0(``$BQ`@`$````$0`8
M`-4#``#A7P$``@```!(`#0!O`0`````````````2````2P$`````````````
M$@```'4$``"E7P$`/````!(`#0"Q!```G50!`+P````2``T`WP,``.1?`0``
M````$@`.`%T"`````````````!(```!)!```D1D!```````2``T`G@0``)@4
M`0``````$@`+`*<``````````````!(```#.`@`````````````2````ZP``
M`$2Q`@`!````$0`8`)<"`````````````!(```!0!```[%\!``0````1``\`
MH@,``"RQ`@``````$``8`"L#`````````````!(```!#`P`````````````2
M````:@``````````````$@```/@``````````````!(```"<!```94\!`#``
M```2``T`%`$`````````````$@```-`#``!TP0(``````!``&`"D!```<5`!
M`(0!```2``T`O```````````````$@```"P"`````````````!(```#C`0``
M```````````2````?0$`````````````$@```,H``````````````!(```#<
M```````````````2````"0$``$"Q`@`$````$0`8`&L#```PL0(`!````!$`
M&``]`0`````````````2````I0(`````````````$@```+P#``!TP0(`````
M`!``&`##!```/50!`%`````2``T`F```````````````$@```.<"````````
M`````!(```!#!```'+$"```````0`!<`-0,`````````````$@```(D#```X
ML0(`!````!$`&`#V`P``C50!`!`````2``T`N0$`````````````$@```*8!
M`````````````!(```!F`P``X1<!`*X!```2``T`&0$`````````````$@``
M`!`#`````````````!(````'`P`````````````2````Q`$``$RQ`@`3````
M$0`8`,<"`````````````!(```"S`@`````````````2````2P(`````````
M````$@```+(!`````````````!(```!+`P`````````````2````CP0``+52
M`0"(`0``$@`-`!<#`````````````!(````>`0`````````````2````=0(`
M````````````$@```!$$```Y7P$`3````!(`#0!X```````````````2````
M6P$`````````````$@```.4#``!M4`$`!````!(`#0`J`0``X!8!```````2
M`````&QI8G!E<FPN<V\N-2XR,@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B
M;&4`7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!?251-7W)E
M9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI
M=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K
M7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E
M<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,
M7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N
M;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!0
M97)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y
M;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A
M;&QO8P!03%]M96UO<GE?=W)A<`!L:6)P=&AR96%D+G-O+C``<'1H<F5A9%]G
M971S<&5C:69I8P!C;&]S90!O<&5N-C0`7U]E<G)N;U]L;V-A=&EO;@!L<V5E
M:S8T`')E860`;&EB8RYS;RXV`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R
M;F-M<`!?7W-T<F1U<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN
M:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H<@!G971P:60`<W1R=&]K`'-T
M<FQE;@!M96US970`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y
M`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S
M=&1E<G(`9V5T=6ED`')E861L:6YK`&5X96-V<`!?7VUE;6-P>5]C:&L`<W1R
M8VAR`')E861D:7(V-`!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T
M<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`;&0M;&EN=7@M87)M
M:&8N<V\N,P!?7W-T86-K7V-H:U]G=6%R9`!?961A=&$`7U]B<W-?<W1A<G0`
M7U]B<W-?<W1A<G1?7P!?7V)S<U]E;F1?7P!?7V5N9%]?`%]E;F0`7U]L:6)C
M7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?
M9V5T<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE
M`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`
M<&%R7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L
M:6)P871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,
M24)#7S(N-`````````````````(``P`"``(``0````(````!``(``@`!``(`
M`0`!``(``@`"``$``@`!``$``0`"``(````"``(``P`#``(``0`"`````@`"
M``,``P`"``$``@`!```````!``$``0`"``$``0````(````"``$``0`"``(`
M``````$````!``$````"``,````````````"`````@`!``$````"``$``@`$
M``$```````$``@`"``(````"``(``@`"``(``0`"`````@`!```````!````
M```!``$`=0,``!`````@````%&EI#0``!`#G!`````````$``0#3`0``$```
M`"`````4:6D-```#`.<$`````````0`!`"("```0`````````!1I:0T```(`
MYP0````````4L0(`%0(``#"Q`@`43```.+$"`!15``!`L0(`%$L``$2Q`@`4
M.0``2+$"`!0M``!,L0(`%%T```RP`@`6!P``$+`"`!8%```4L`(`%A@``!BP
M`@`6*@``'+`"`!86```@L`(`%CX``"2P`@`66@``*+`"`!9%```LL`(`%EX`
M`#"P`@`66P``-+`"`!8,```XL`(`%E\``#RP`@`640``0+`"`!9"``!$L`(`
M%C@``$BP`@`6-```3+`"`!9&``!0L`(`%@\``%2P`@`6'```6+`"`!8O``!<
ML`(`%DT``&"P`@`67```9+`"`!9D``!HL`(`%DD``&RP`@`65P``<+`"`!8&
M``!TL`(`%E@``'BP`@`64@``?+`"`!8A``"`L`(`%F$``(2P`@`6%```B+`"
M`!8P``",L`(`%@(``)"P`@`6"```E+`"`!8=``"8L`(`%B,``)RP`@`6:```
MH+`"`!8H``"DL`(`%B(``*BP`@`65```K+`"`!8W``"PL`(`%F```+2P`@`6
M'@``N+`"`!9F``"\L`(`%DX``,"P`@`6:P``Q+`"`!8_``#(L`(`%F4``,RP
M`@`6"@``T+`"`!8E``#4L`(`%D```-BP`@`6"P``W+`"`!9B``#@L`(`%CH`
M`.2P`@`62```Z+`"`!8F``#LL`(`%CT``/"P`@`62@``]+`"`!9I``#XL`(`
M%A$``/RP`@`6#@```+$"`!8G```$L0(`%BD```BQ`@`6'P``#+$"`!85```0
ML0(`%D<```A`+>E'`0#K"("]Z`3@+>4$X)_E#N"/X`CPON5,FP$``,:/XAG*
MC.),^[SE`,:/XAG*C.)$^[SE`,:/XAG*C.(\^[SE`,:/XAG*C.(T^[SE`,:/
MXAG*C.(L^[SE`,:/XAG*C.(D^[SE`,:/XAG*C.(<^[SE`,:/XAG*C.(4^[SE
M`,:/XAG*C.(,^[SE`,:/XAG*C.($^[SE`,:/XAG*C.+\^KSE`,:/XAG*C.+T
M^KSE`,:/XAG*C.+L^KSE`,:/XAG*C.+D^KSE`,:/XAG*C.+<^KSE`,:/XAG*
MC.+4^KSE>$?`1@#&C^(9RHSBR/J\Y0#&C^(9RHSBP/J\Y0#&C^(9RHSBN/J\
MY0#&C^(9RHSBL/J\Y0#&C^(9RHSBJ/J\Y0#&C^(9RHSBH/J\Y0#&C^(9RHSB
MF/J\Y0#&C^(9RHSBD/J\Y0#&C^(9RHSBB/J\Y0#&C^(9RHSB@/J\Y0#&C^(9
MRHSB>/J\Y0#&C^(9RHSB</J\Y0#&C^(9RHSB:/J\Y0#&C^(9RHSB8/J\Y0#&
MC^(9RHSB6/J\Y0#&C^(9RHSB4/J\Y0#&C^(9RHSB2/J\Y0#&C^(9RHSB0/J\
MY0#&C^(9RHSB./J\Y0#&C^(9RHSB,/J\Y0#&C^(9RHSB*/J\Y0#&C^(9RHSB
M(/J\Y0#&C^(9RHSB&/J\Y0#&C^(9RHSB$/J\Y0#&C^(9RHSB"/J\Y7A'P$8`
MQH_B&<J,XOSYO.5X1\!&`,:/XAG*C.+P^;SE`,:/XAG*C.+H^;SE`,:/XAG*
MC.+@^;SE`,:/XAG*C.+8^;SE`,:/XAG*C.+0^;SE`,:/XAG*C.+(^;SE`,:/
MXAG*C.+`^;SE`,:/XAG*C.*X^;SE`,:/XAG*C.*P^;SE`,:/XAG*C.*H^;SE
M`,:/XAG*C.*@^;SE`,:/XAG*C.*8^;SE`,:/XAG*C.*0^;SE`,:/XAG*C.*(
M^;SE`,:/XAG*C.*`^;SE`,:/XAG*C.)X^;SE`,:/XAG*C.)P^;SE`,:/XAG*
MC.)H^;SE`,:/XAG*C.)@^;SE`,:/XAG*C.)8^;SE`,:/XAG*C.)0^;SE`,:/
MXAG*C.)(^;SE`,:/XAG*C.)`^;SE`,:/XAG*C.(X^;SE`````/"U2_(X%\#R
M`@>)L#MH!9`%J`21!*D#D@.J!Y/_]S;O0?+@8L#R`0)!\EAPP/(!`!%&!/"W
M^TOR1!/`\@(#'7@`+7C02_)`%,#R`@0@:/_WT.^0^!XT`D8@:$/P`@."^!XT
M__?&[P6;!3.S\8!/D/@>)$+P`0*`^!XD?=*8`$SR6";_]\CN!)Q+\B01P/("
M`06:P/("!DEH1O*`,P$JP/(!`P5&(&A&^/!<:V!&\H0SJ6#`\@$#3_`$`>M@
M1OCT',B_(QTH8,2_!.N"!`7Q#`$%W5/X!`NC0D'X!`_YT0+Q@$$`)`,Q`)16
M^.@,`S)%^"%`*T9$]I5QP/(!`?_W$N\$1FBS5OCH#/_W6NY&\C`0!JG`\@$`
M`_`O^3BS5OCH#/_W*.[_]_+N!YH[:"!&FD(XT0FP\+W_]V+N3/)8(\#R`@-#
M^.@,>+-+\D`4P/("!/_W"NX@:/_W3.^`^(U6=>=6^.@,__<:[P1&R^=6^.P,
M8+$$\/'ZT>=+\DP11O)<(,#R`@'`\@$`__>8[@:I1O+,`,#R`0`#\._X1OCL
M#``HO-#FY__W\NT!(/_W9.X`OT_P``M/\``.`KQJ1@2T`;3?^!#`3?@$S0-(
M!$O_]SKN__?V[N%?`0#A%P$`I5\!`!0PG^44()_E`S"/X`(@D^<``%+C'O\O
M`1?__^HPE@$`%`$```=+2_(L$,#R`@`;&@8K!=E`\@`#P/(``P.Q&$=P1P"_
M+[$"`$OR+!-+\BP0P/("`\#R`@`9&HD0`>O1<4D0!=!`\@`#P/(``P.Q&$=P
M1P"_$+5+\E\4P/("!"-X&[G_]\__`2,C<!"]"+5*]OQ@P/("``-H$[F]Z`A`
MT^=`\@`#P/(``P`K]M"81_3G+>GP3TOR.!.M]3]]P/("`P#Q,`8`\7`'&Y,<
MK!MH`"6V1KQ&&I"]DU[X"#\0-`&5&[KF1=[X!!!$^!`\3_```T3X#%Q/Z@$J
M3^H1:T_J$2;-^`"P3^H!80KT?P)"Z@$"W>D``4#J`@!!Z@,!`D8&]']`"T9"
MZ@`"3_```4/J`0-$Z0(CT-$-\6@.#?4:?'%&_ND"9]'I'"/1Z1)%T>D&`6)`
M:T!00%E`1D!/0+(9YD5/ZM9X3_```TCJ1PA"Z@@"SND@(^/1&I\`(I)&#?64
M?M?I`#37Z0@!H4:81DY&`"/-Z1(!FT;7Z00!<P'-Z0"K0^K88]?I`JO7Z09G
MS>D&B=Q&TT;-Z0IG1T;=Z1*:>@'=Z1QG&D,/]KAEU>D`11;K"0;-Z0@!1^L*
M![!&%.L(!+I&W>D*9T7K"@6@1G!`7$8+Z@`+J49E1GE`7D:C1JP'`91<1@SJ
M`0R@"-WI"C08ZP((9T:#Z@8#2?$`"7Q`K$8>1@&;&.L&`D#JA7!#ZIL#`9-)
MZP0#DD851LWI%+P>1EM&FP<`D]WI`"-/\``+6T9/\``)`D-9`<WI`E9!ZMIA
MD$;=Z0@CW>D>18+J"`*#Z@D#S>D,B9!&F4;=Z0HCS>D`JQ(9:T'=Z09%!.H(
M!`7J"06@1E1&8`%<1@_VY%S<Z0"\YPX;ZP(+3.L##-WI"#3-Z0Z\0.H!"T'J
M!PR#Z@@#S>D$O&Q`W>D.O``EW>D&B1OK`PM,ZP0,049&1HP(!)E$ZHETL@<;
MZP$`0NH$`DSQ``$L1H-&$T:,1LWI$+S=Z2"\`"'-Z0XTB4:`1D_J21?-Z02\
M1^K09]WI`JM/ZD@63^K980`@"NH""@OJ!0O=Z0@CS>D"J]WI!*O=Z0!%$NL*
M`D/K"P,/]CA;V^D`JQKK`@I+ZP,+W>D,(R+J!`0CZ@4%(D8K1D?J!@1!Z@<%
MS>D$1=WI`D440QU#&NL$"DOK!0M61E]&W>D`JU%&C`@$F1;K`0I/\``!1_$`
M"]WI`&?-Z1:K3_``"\WI`@$`(43JAW1?1MWI(KRR!R)#>P$#DU9&S>D`O)-&
M3_``#`_VL$34Z0`TS>D$O/`.W>D`O$#J1Q#-Z0!G$^L+`T3K#`3=Z02\&D8C
M1MWI$$4%Z@P%!.H+!$_P``RK1@.=HD9%ZM9D`Y3=Z0Q%=@$"EJ0874'=Z0XC
MW>D"9R+J"`(CZ@D#2NH""DOJ`PL4ZPH$1NH`!D_JB7-%ZPL%0^J8`Q3K!@I/
MZHAR1?$`"QI#5$9=1LWI$$401MWI)$4/]AA#T^D`(]!&S>D,`4_P``D2&=WI
M%JMK0=WI#$5/ZDD73^I(%@KJ!`H+Z@4+W>D.14?JV&=/ZMEAI!A=0=WI!"/-
MZ0)%W>D`12+J!`0CZ@4%2NH$"DOJ!0O=Z0)%%.L*!$?J!@I%ZPL%0>H'"\WI
M`JL`)]WI`*M11HX(`ID4ZP$*1?$`"]WI`$7-Z1:K3_``"UE&4$9&ZH5VH@<R
M0]WI)D5+`0`FDT;-Z0)G`Y-61@_V:#/3Z0`C#T;-Z0Z\P`X2&<WI`&=K0=WI
M$$5`ZD$0`"$%Z@P%!.H+!$_P``RK1@.=HD9%ZM9D`Y3=Z01%=@$"EJ08W>D"
M9UU!W>D,(P9#(NH(`B/J"0-*Z@(*2^H#"Q3K"@1/ZHES1>L+!4/JF`,4ZP8*
M3^J(<D7Q``L:0U1&T$9=1A!&S>D014_P``G=Z2A%3^I)%P_VT"/3Z0`C1^K8
M9\WI!`%/ZD@6$AG=Z1:K:T'=Z01%3^K980KJ!`H+Z@4+W>D,1:0874'=Z0XC
MS>D"1=WI`$4BZ@0$(^H%!4KJ!`I+Z@4+W>D"113K"@1'Z@8*1>L+!4'J!PO-
MZ0*K`"?=Z0"K44:."`*9%.L!"D7Q``O=Z0!%S>D6JT_P``M91E!&1NJ%=J('
M,D/=Z2I%2P$`)I-&S>D"9P.35D8/]BPCT^D`(P]&S>D`9\`.$AE`ZD$0:T'=
MZ1!%S>D0O``A!>H,!03J"P1/\``,JT8#G:)&1>K69`.4W>D.178!`I:D&-WI
M`F==0=WI!",&0R+J"`(CZ@D#2NH""DOJ`PL4ZPH$3^J)<T7K"P5#ZI@#%.L&
M"D_JB')%\0`+&D-41M!&74801LWI#D5/\``)W>DL14_J21</]I03T^D`(T?J
MV&?-Z0P!3^I(%A(9W>D6JVM!W>D,14_JV6$*Z@0*"^H%"]WI!$6D&%U!W>D0
M(\WI`D7=Z0!%(NH$!"/J!05*Z@0*2^H%"]WI`D44ZPH$1^H&"D7K"P5!Z@<+
MS>D"JP`GW>D`JU%&C@@"F13K`0I%\0`+W>D`1<WI%JM/\``+64901D;JA7:B
M!S)#W>DN14L!`":31LWI`F<#DU9&#_;P`]/I`",/1LWI`&?`#A(90.I!$&M!
MW>D.1<WI#KP`(07J#`4$Z@L$3_``#*M&`YVB1D7JUF0#E-WI$$5V`0*6I!C=
MZ0)G74'=Z0PC!D,BZ@@"(^H)`TKJ`@I+Z@,+%.L*!$_JB7-%ZPL%0^J8`Q3K
M!@I/ZHAR1?$`"QI#5$;01EU&$$;-Z1!%3_``"=WI,$5/ZDD7#_98`]/I`"-'
MZMAGS>D$`4_J2!82&=WI%JMK0=WI!$5/ZMEA"NH$"@OJ!0O=Z0Q%I!A=0=WI
M#B/-Z0)%W>D`12+J!`0CZ@4%2NH$"DOJ!0O=Z0)%%.L*!$?J!@I%ZPL%0>H'
M"\WI`JL`)]WI`*M11HX(`ID4ZP$*1?$`"]WI`$7-Z1:K3_``"UE&4$9&ZH5V
MH@<R0]WI,D5+`0`FDT;-Z0)G`Y-61@_RM'/3Z0`C#T;-Z0!GP`X2&4#J01!K
M0=WI$$7-Z1"\`"$%Z@P%!.H+!$_P``RK1@.=HD9%ZM9D`Y3=Z0Y%=@$"EJ08
MW>D"9UU!W>D$(P9#(NH(`B/J"0-*Z@(*2^H#"Q3K"@1/ZHES1>L+!4/JF`,4
MZP8*3^J(<D7Q``L:0U1&T$9=1A!&S>D.14_P``G=Z31%3^I)%P_R''/3Z0`C
M1^K89\WI#`%/ZD@6$AG=Z1:K:T'=Z0Q%3^K980KJ!`H+Z@4+W>D$1:0874'=
MZ1`CS>D"1=WI`$4BZ@0$(^H%!4KJ!`I+Z@4+W>D"113K"@1'Z@8*1>L+!4'J
M!PO-Z0*K`"?=Z0"K44:."`*9%.L!"D7Q``O=Z0!%S>D6JT_P``M91E!&1NJ%
M=J(',D/=Z39%2P$`)I-&S>D"9P.35D8/\GACT^D`(P]&P`X2&4#J01!K0=WI
M#D7-Z0Z\`"$%Z@P%!.H+!*M&`YVB1LWI`&=%ZM9D`Y3=Z1!%=@$"EJ08W>D"
M9UU!W>D,(P9#(NH(`B/J"0-*Z@(*2^H#"Q3K"@1/ZHES1>L+!4/JF`,4ZP8*
M3^J(<D7Q``L:0U1&T$9=1A!&S>D"14_P``G=Z3A%3^I)%P_RY%/3Z0`C1^K8
M9\WI!`%/ZD@6$AG=Z1:K:T'=Z01%3^K980KJ!`H+Z@4+W>D,1:0874'=Z0XC
MS>D,1=WI`$4BZ@0$(^H%!4KJ!`I+Z@4+W>D,113K"@1'Z@8*1>L+!4'J!PO-
MZ0RKW>D`JU%&C@@,F13K`0I/\``!1?$`"]WI`$7-Z1"K3_``"T_J2Q=&ZH5V
MH@<R0]WI.D5'ZMIG`)<01LWI#`$/\D!2TND`$D_J2A8`)PD9:D'=Z0)%S>D6
M$MWI#!(,0!5`W>D6(\WI`D7=Z0Y%$AEK01!&&4;=Z00T(^H(`R3J"00:1B-&
MW>D"111#'4,`(R)&3^K;9`&4A!A!ZP4%W>D``0`BS>D"(S!#3^J)<R(8`Y-%
M\0`#3_``"4E&3_``"1Q&$T8#FAA&S>D6-$+JF`(#DMWI/$461D_JB'("DMWI
M`B-+`3)#`";-Z0)G!D8#DY!&#_*,0]/I`",/1LWI#HG`#A(9W>D0B6M!W>D.
M1<WI`&=`ZD$0">H%"0.=".H$"$7JUF0#E-WI!$5V`0*6I!C=Z0)G74'=Z0PC
M!D,BZ@H"(^H+`TCJ`@A)Z@,)3^J+<Q3K"`1#ZIH#3^J*<D7K"04:0Q3K!@A/
M\``+1?$`"=WI/D7"1LWI!(F01@_R!$/3Z0`C3_``"<WI`HD2&=WI%HEK0=WI
M`D5/ZDL73^I*%@CJ!`@)Z@4)W>D,14?JVF=/ZMMAI!A=0=WI#B/-Z0Q%W>D`
M12+J!`0CZ@4%2.H$"$GJ!0G=Z0Q%`",4ZP@$1^H&"$7K"05!Z@<)S>D,B=WI
M`(E!1HX(#)D4ZP$(3_```47Q``G=Z0!%S>D0B4_P``E&ZH5VH@<-1C)#0*E$
M1I!&`"+1Z0`!S>D`(^,.`)/5H]/I`"/-Z0R)$AA+0=WI!`$`Z@@`H$8`G`'J
M"0&I1LWI!`%$ZD44`)3=Z0Y%049.`=WI!`&D&,WI!(E=0=WI`B,CZ@L#(NH*
M`AE#2T;;#@&3$$/=Z0`C`!E/ZIL#0NH&`FE!$.L""$_JBW5!\0`)1>J:!4=&
M3^J*=$*N.$;(1D_P``O-Z0YX1.H%!T7J`PA91K"CT^D`(SQ&UND`JT5&S>D6
M14_J01G=Z1!%$NL*`D/K"P.Z1D_P``O-Z1"K!>H+!=WI`KP\0,WI`$4;ZP(+
MW>D,14SK`PS=Z00C2>K0:4_J0!@DZ@(")>H#`]WI`$7:1DCJ"0@40QU#%.L*
M`D7K#`,2ZP@+W>D$B4/Q``S-Z1B\3_``#,WI`+Q+1@&:GP=#1IX'2T:="$2K
M1^J8!T_J0AO3Z0")S>D$B4;J!PA'Z@4)AJ;6Z0!60T9,1MWI%HG-Z0(TB.H#
M"-WI!#3M&`";9D%+ZM-KW>D.-#=&A@>#Z@@#F$;=Z0PC4AE/ZI$%>T$2ZP@"
M'T8`FT_J0QI'\0`#2NH+"(\'$NL("T?JD`=#\0`,1JO81D;J!PK3Z0`!1^H%
M"]WI`C151EY&S>D$5FM`9Z75Z0!%X4;-Z0Z))!A/\``)34'=Z1@23^I)&T_J
M2!I90-WI$"-+ZMAK`"`2&4KJ"P9K05(80_$``Q+K!@K=Z0!G0_$`"\WI$*M/
M\``+O0=?1D7JE@561MWI`*M31IP'6T:9"$BK1>H!#``AT^D`(T3J!0O-Z0`!
M>0$!D4BAT>D``=WI!$6`&,WI#+Q9083J"P0!FXM&W>D.$D/JUF,!DV%`\@Y"
MZD<23^J9`PQ&`IE`&$OQ``$`&8M&3^I&$0"12_$``=WI`$440Q#K!`M/ZHAP
M0?$`#$_JB7%!ZI@!WND`B5Q&94;-Z0Y%`"7-Z1:)0>H#"4#J`0C-Z0!%2D8G
MI-3I`#1!1MWI#(G-Z0(23_``"8CJ`0C=Z182#?6@?EL85$$81B%&W>D0-`"<
M@^H(`^(.!)P`&0&<0?$``4+J1!(`G$_J1!K$&$KJ`@A!\0`%%.L("DRL1?$`
M"\WI$*O01M3I`*NY![`'0>J6`;L(S>D6JT#J`0I!Z@,+W>D"-%5&W>D6$FM`
M7D;-Z0163^I)&QY&".``OYEY@EH`````H>O9;@`````/]H1DU.D`-$OJV&M/
MZD@:6QA402%&W>D.171`)D8,G!@90?$``8092NH+!MWI`*M!\0`%I!E%\0`%
MS>D.15Y&3_``"[$'7T9!ZIH!W>D`JR9&5$:@!UQ&HPA.K-3I`$7-Z19%0.H!
M!$'J`P7=Z182HD9[`:M&S>D,JP_V#&S<Z0"\0^K68]WI!$4;ZP$+`9-,ZP(,
MW>D0$H3J"@3R#F%`0NI'$D_JF0,,1@*9&^L!`$SQ``$`&8M&3^I&$0"12_$`
M`=WI`$440Q#K!`I/ZHAP0?$`"T_JB7%!ZI@!WND`B51&74;-Z1!%`"7-Z1:)
M0>H#"4#J`0C-Z0!%2D8/]HA4U.D`-$%&W>D,B<WI`A(-]:Q^B.H!"-WI%A);
M&%1!&$8A1MWI#C0`G(/J"`/B#@2<`!D!G$'Q``%"ZD02`)Q/ZD0:Q!A*Z@((
M0?$`!13K"`I2K$_JAW%%\0`+0>J6`;`'U.D`5KL(T$;91LWI#HE/\``)S>D6
M5D'J`P;=Z0(T0.H!!=WI%A)/ZDD;:T#-Z0162^K::T_J2AH>1@_V[$34Z0`T
M6QA402%&W>D0171`)D8,G!@90?$``8092NH+!MWI`*M!\0`%I!E%\0`%S>D0
M15Y&3_``"[$'7T9!ZIH!W>D`JR9&5$:@!UQ&HPA4K-3I`*O=Z01%S>D6JT#J
M`0I!Z@,+W>D6$LWI#*N$Z@H$#_9X3-SI`+Q[`4/JUF,!DQOK`0M/ZID#3.L"
M#-WI#A+R#F%`0NI'$@Q&`ID;ZP$`3/$``0`93_``#(M&3^I&$0"12_$``=WI
M`$440Q#K!`I/ZHAP0?$`"T_JB7%!ZI@!WND`B51&74;-Z0Y%`"7-Z1:)0>H#
M"4#J`0C-Z0!%2D8/]O@TU.D`-$%&W>D,B<WI`A(-];A^B.H!"-WI%A);&%1!
M&$8A1MWI$#0`G(/J"`/B#@2<`!D!G$'Q``%"ZD02`)Q/ZD0:Q!A*Z@((0?$`
M!13K"`I8K$_JAW%%\0`+0>J6`;`'U.D`5KL(T$;91LWI$(E/\``)S>D65D'J
M`P;=Z0(T0.H!!=WI%A)/ZDD;:T#-Z0162^K::T_J2AH>1@_V6#34Z0`T6QA4
M02%&W>D.171`)D8,G!@90?$``8092NH+!MWI`*M!\0`%I!E%\0`%S>D615Y&
M3_``"[$'7T9!ZIH!W>D`JR9&5$9/ZD8:H`=<1J,(6JQ/ZD<;U.D`14OJUFO-
MZ0!%0.H!!$'J`P7=Z002S>D,16%`:D`/]MPEU>D`11-&"D;=Z0`!`!EI001&
M#4;=Z1`!64`"FU!`S>D``>08`)M%\0`%3^J9`>(83^J(=$7Q``/-Z0`C3^J)
M=4KJ"P+=Z0"K1>J8!47J`0,:ZP(*1.H%`DOQ``O-Z0*K$4;31AI&S>D`O`&;
MWND`B0WUO'[-Z0X23^I#&]WI##1+0!A&#_94)-3I`#03ZP@#1.L)!-WI%HE/
MZH=Y)48<1@";B.H`"$GJE@E+ZM-K!)OD&`";1?$`!13K"`)/ZH9X3^I#&D7Q
M``-+Z@H`O0@2ZP`*3_```D/Q``M)Z@4#$49(Z@D"F4;=Z0XTWND`9Y!&4T#-
MZ02)W>D"B5!&'$8/]MP3T^D`(\WI$*N(Z@0(DAE/ZD$;>T%+ZMIK3^I*&D1&
M'T8,FPWUP'[6&$?Q``<R&4KJ"P1'\0`#$NL$"MWI`$5#\0`+S>D6JT_JA7D`
M)4GJE`E41LWI`D7=Z0!%`YI/ZH1XWND`-*\(3^I"&P_V;!;6Z0!6#?7$?LWI
M`#1(Z@D#2>H'!-WI!'C-Z0PT7T`"G#I&W>D`>$OJU&L.G.T91NL(!MWI$(E/
MZH%Y-T8N&0*<B.H""$?Q``=)ZI`)3^I$&A;K"`1+Z@H"1_$`!13K`@M/ZI$'
M1?$`#$GJ!P5;1D_J@'AD1LWI$#0`)-[I``$C1DCJ"02H1MWI#%8G1LWI#GAE
M0`_VV`G9Z0")6D9/ZD,;+D;=Z19%&.L`"$OJTFN$Z@8$2>L!"4_J0AH-]<A^
M)D8$G!CK!`!)\0`!A!E*Z@L`W>D"JT'Q``4D&$7Q``7-Z19%3^J+>4_P``M)
MZIH)HD;=Z0)%S>D`J][I`*L-]<Q^3^J$>*\(2.H)!$GJ!P591E!&H$8!G*E&
M1T;-Z0*)3^I$&]WI#D7=Z1")3^J#>7Q`#_8X!]?I`&>(Z@0(2>J2"3883T$`
MF4OJT6L,F788`)E'\0`'%NL(`$_J@GA/ZD$:1_$``4OJ"@2?"!#K!`I(Z@D`
M0?$`"TGJ!P'=Z0*)5$;>Z0`C74:(Z@`(S>D,1<WI!`$`)49&#_+4>=GI`(D.
MF4_J11L8ZP((2^K::TGK`PE/ZDH:0D92&$M&W>D6B4/Q``,-]=!^B.H&"$9&
MD!E*Z@L&0_$``1#K!@K=Z0!G0?$`"\WI$*M/\``+3^J'>5]&2>J6"59&W>D`
MJUE&3^J*>(L(3_``"DGJ`PQ/\``+S>D`JTCJ"0O=Z02:>P'>Z0`!#?74?HGJ
M"PD!D\WI#KP`(TI&#_(X>MKI`)H9ZP`)2NL!"@&90>K680&1`IG31LI&W>D,
MB1KK`0!/ZH5YB.H""$OQ``$0ZP@`3^K68HM&3^I&$0"12_$``8-&0NI'$HQ&
MW>D``4GJE`E/ZH1X$$.I"!OK``M/\``$3/$`#,WI%KQ:1LWI`"-(Z@D"`"/-
MZ0(T2>H!`]WI#HD11MWI`$4:1HCJ`0B)Z@()WND`JPWUW'[-Z0P2:P%"1@.3
M2T8/\HQIV>D`B1CK"@A)ZPL)JT9`1D_JU&A(ZDL8W>D0JP.=BNH""MWI`!*+
MZ@,+!)O-Z1"K1>K49!#K`PI/ZD$3`I-)\0`+$)NY"`.43_``"1KK`PK=Z0(T
M;*Q+\0`+0^H(`YA&NP=#ZI8#!9,:ZP@*&$9/ZH9S!)-+\0`+W>D$(]!&S>D0
MJT_J21L+0P)#U.D``4OJVFL?1MWI##051A9&*T,\0\WI&`%/ZDH:&$8A1MWI
M%C3-Z01G`T`,0,WI`C3=Z0Q%W>D8`31`)D8/\LA4U.D`-,`8#IMA001&XA@-
M1MWI`@%%\0`#,$-+Z@H&$AA#\0`#S>D"(]WI`*M;1IT'4T;=Z0*KF`@`(QKK
M!@K=Z0!G2_$`"\WI%JM/\``+S>D`JT#JAW"T!T3J``H`),WI`C1%ZI8%`9RY
M"-WI!&=%Z@$+WND``0WU%GYD`0.4W>D014;J"@/-Z0ZK'$`/\CA<W.D`O`R;
M(D8&Z@H$`YX;ZP`+3.L!#!OK`PL`FT+J!`HW1@">3/$`#!OK"@M/ZM-D3^I#
M$P*31^K69P&;3/$`#`.73^J)<=WI`F=!ZI@!1.I#%$_JB'`F0W"L&^L&"T_J
MF0/=Z0YG3_``"=A&3/$`#,WI$+Q`Z@$+0>H##-3I``$`(P`DS>D"-$_J210#
ME$;J"P/=Z19%S>D,O!Q`!)LB1@;J"P0/\I!+V^D`JP.>&NL`"D;JV&=+ZP$+
M4$9"Z@0*`Y=/ZMAD5D80ZP,*3^I($P*32_$`"QKK!@K=Z0)G1.I)%$OQ``LF
M0S1&`9X!G1KK!`IRK$OQ``NQ!P">JPA51LWI%JM!ZI8!L`<`)LWI`%9`Z@$*
M0>H#"]3I``$`(P`DS>D"-`&<W>D,9\WI!*MD`0.4W>D014;J"@,/\OP\W.D`
MO!Q`#IL;ZP`+3^J(<")&!NH*!`.>3.L!#!OK`PL`FT+J!`I,\0`,-T8`GMP.
M6P$"DQOK"@L!FT?JUF<#ETSQ``S=Z0)G3^J)<43J0Q1!ZI@!)D-TK!OK!@M/
MZID#W>D$9T_P``G81DSQ``S-Z1"\0.H!"T'J`PS4Z0`!`",`),WI`C1/ZDD4
M`Y1&Z@L#W>D61<WI#KP<0`R;(D8&Z@L$#_)4.]OI`*L#GAKK``I&ZMAG2^L!
M"U!&0NH$"@.73^K89%9&$.L#"D_J2!,"DTOQ``L:ZP8*W>D"9T3J211+\0`+
M)D,T1@&>`9T:ZP0*=JQ+\0`+L0<`GJL(54;-Z1:K0>J6`;`'`";-Z0!60.H!
M"D'J`PO4Z0`!`",`),WI`C0!G-WI#F?-Z0RK9`$#E-WI$$5&Z@H##_+`+-SI
M`+P<0`2;&^L`"T_JB'`B1@;J"@0#GDSK`0P;ZP,+`)M"Z@0*3/$`##=&`)[<
M#EL!`I,;ZPH+`9M'ZM9G`Y=,\0`,W>D"9T_JB7%$ZD,40>J8`29#>*P;ZP8+
M3^J9`]WI#&=/\``)V$9,\0`,S>D0O$#J`0M!Z@,,U.D``0`C`"3-Z0(T3^I)
M%`.41NH+`]WI%D7-Z02\'$`.FR)&!NH+!`_R&"O;Z0"K`YX:ZP`*1NK89TOK
M`0M01D+J!`H#ET_JV&161A#K`PI/ZD@3`I-+\0`+&NL&"MWI`F=$ZDD42_$`
M"R9#-$8!G@&=&NL$"GJL2_$`"[$'`)ZK"%5&S>D6JT'JE@&P!P`FS>D`5D#J
M`0I!Z@,+U.D``0`C`"3-Z0(T`9S=Z01GS>D.JV0!`Y3=Z1!%1NH*`P_RA!S<
MZ0"\'$`,FQOK``M/ZHAP(D8&Z@H$`YY,ZP$,&^L#"P";0NH$"DSQ``PW1@">
MW`Y;`0*3&^L*"P&;1^K69P.73/$`#-WI`F=/ZHEQ1.I#%$'JF`$F0WRL&^L&
M"T_JF0/=Z0YG3_``"=A&3/$`#,WI$+Q`Z@$+0>H##-3I``$`(P`DS>D"-$_J
M210#E$;J"P/=Z19%S>D,O!Q`!)LB1@;J"P0/\MP+V^D`JP.>&NL`"D;JV&=+
MZP$+4$9"Z@0*`Y=/ZMAD5D80ZP,*3^I($P*32_$`"QKK!@K=Z0)G1.I)%$OQ
M``LF0S1&`9X!G1KK!`I^K$OQ``NQ!P">JPA51LWI%JM!ZI8!L`<`)LWI`%9`
MZ@$*0>H#"]3I``$`(P`DS>D"-`&<W>D,9\WI!*MD`0.4W>D014;J"@,/\D@,
MW.D`O!Q`#IL;ZP`+3^J(<")&!NH*!`.>3.L!#!OK`PL`FT+J!`I/ZHEQ-T8`
MGD_JTV1/ZD,3`I-!ZI@!!^"AZ]EN`````-R\&X\``````9M'ZM9G`Y=,\0`,
MW>D"9QOK"@M$ZD,43^J9`T;J!`9!Z@,%0.H!!$SQ``P;ZP8+3_``"=WI!&=,
M\0`,V$;-Z1"\`".C1JQ&`"3-Z0(T3^I)%`.41NH+`]WI%D6`J<WI#KP<0-'I
M``$,FR)&!NH+!`_V=&O;Z0"K`YX:ZP`*1NK89TOK`0M01D+J!`H#ET_JV&16
M1A#K`PI/ZD@3`I-+\0`+&NL&"MWI`F=$ZDD42_$`"R9#-$8!GAKK!`H!G$OQ
M``O-Z1:KL0<`GJ,(549!ZI8!L`=`Z@$$`";-Z0!60>H#!:)&`",`),WI`C0!
MG*M&W>D.9X*IS>D,JV0!`Y3=Z1!%1NH*`]'I``$<0`_VV%S<Z0"\!)LB1@;J
M"@0#GAOK``M,ZP$,&^L#"P";0NH$"C=&`)Y/ZHEQ3^J(<$_JTV1/ZD,3`I-'
MZM9G`9M!ZI@!`Y=,\0`,W>D"9QOK"@M$ZD,43^J9`T;J!`9!Z@,%0.H!!$SQ
M``P;ZP8+3_``"=WI#&=,\0`,V$;-Z1"\`".C1JQ&`"3-Z0(T3^I)%`.41NH+
M`]WI%D6$J<WI!+P<0-'I``$.FR)&!NH+!`_V+%O;Z0"K`YX:ZP`*1NK89TOK
M`0M01D+J!`H#ET_JV&161A#K`PI/ZD@3`I-+\0`+&NL&"MWI`F=$ZDD42_$`
M"R9#-$8!GAKK!`H!G$OQ``O-Z1:KL0<`GJ,(549!ZI8!L`=`Z@$$`";-Z0!6
M0>H#!:)&`",`),WI`C0!G*M&W>D$9X:IS>D.JV0!`Y3=Z1!%1NH*`]'I``$<
M0`_VD$S<Z0"\#)LB1@;J"@0#GAOK``M,ZP$,&^L#"P";0NH$"C=&`)Y/ZHEQ
M3^J(<$_JTV1/ZD,3`I-'ZM9G`9M!ZI@!`Y=,\0`,W>D"9QOK"@M$ZD,43^J9
M`T;J!`9!Z@,%0.H!!$SQ``P;ZP8+3_``"=WI#F=,\0`,V$;-Z1"\`".C1JQ&
M`"3-Z0(T3^I)%`.41NH+`]WI%D6(J<WI#+P<0-'I``$$FR)&!NH+!`_VX#O;
MZ0"K`YX:ZP`*1NK89TOK`0M01D+J!`H#ET_JV&161A#K`PI/ZD@3`I-+\0`+
M&NL&"MWI`F=$ZDD42_$`"R9#-$8!GAKK!`H!G$OQ``O-Z1:KL0<`GJ,(549!
MZI8!L`=`Z@$$`";-Z0!60>H#!:)&`",`),WI`C0!G*M&W>D,9XJIS>D$JV0!
M`Y3=Z1!%1NH*`]'I``$<0`_V1#S<Z0"\#ILB1@;J"@0#GAOK``M,ZP$,&^L#
M"P";0NH$"C=&`)Y/ZHEQ3^J(<$_JTV1/ZD,3`I-'ZM9G`9M!ZI@!`Y=,\0`,
MW>D"9QOK"@M$ZD,43^J9`T;J!`9!Z@,%0.H!!$SQ``P;ZP8+3_``"=WI!&=,
M\0`,V$;-Z1"\`".C1JQ&`"3-Z0(T3^I)%`.41NH+`]WI%D6,J<WI#KP<0-'I
M``$,FR)&!NH+!`_VF"O;Z0"K`YX:ZP`*1NK89TOK`0M01D+J!`H#ET_JV&16
M1A#K`PI/ZD@3`I-+\0`+&NL&"MWI`F=$ZDD42_$`"R9#-$8!GAKK!`H!G$OQ
M``O-Z1:KL0<`GJ,(549!ZI8!L`=`Z@$$`";-Z0!60>H#!:)&`",`),WI`C0!
MG*M&W>D.9XZIS>D,JV0!`Y3=Z1!%1NH*`]'I``$<0`_V_!S<Z0"\!)LB1@;J
M"@0#GAOK``M,ZP$,&^L#"P";0NH$"C=&`)Y/ZHEQ3^J(<$_JTV1/ZD,3`I-'
MZM9G`9M!ZI@!`Y=,\0`,W>D"9QOK"@M$ZD,43^J9`T;J!`9!Z@,%0.H!!$SQ
M``Q/\``)&^L&"T]&W>D,B4SQ``Q>1LWI&+P`(Z-&K$8`),WI`C1\`0.4W>D6
M14CJ"P.0J<WI!&<<0,WI$+S1Z0`!`"4B1@CJ"P0/]D@9V>D`B=WI!+P8ZP`(
M#IM)ZP$)`YY?1DE&0NH$"1CK`P)&ZMMF0?$``UE&`Y9)`0*1_`X!GD3J3!3=
MZ0)X$NL)`D/Q``,G0[$'`9P2ZP<+`)Y#\0`,S>D6O"]&HPA!ZI8!L`=`Z@$*
M7D9!Z@,+DJG01M'I`#391MWI$`'-Z0Z)S>D"-``C`"3-Z0`T0.H*!-WI&*MK
M`0&3`9D*Z@0*W>D"(P1&0$8/]J`)V>D`B4'JUF$!D1+K"`($Z@`$0^L)`T3J
M"@201@I&#)D8ZP$(3^I&$0"10_$`"=WI``$8ZP0*W>D$14_P``%`Z@(`2?$`
M"P)&JP<`(,WI``$!DQKK`@@!FD_JE`!+\0`)0.J%<$+JE`.D!P&3J0@`E``E
MS>D,B0`D3_``"<WI`D7=Z0!%2T9"1MWI#HD$0PU#60$#D92IJT:B1LWI!*O1
MZ0"\B.H$"`_V``'1Z0`!&^L`"T_JTF!,ZP$,`YE`ZD,00>K280.1W>D61;D(
MA.H(!*!&$)P;ZP0$3/$`!:)&5`$"E!KK"`3=Z0*)1?$`!4_P``E(Z@`(%.L(
M"D_JAG1%\0`+O0=%ZI8%S>D0JT7J`0Q$Z@4+W>D$1=!&S>D"O$_J21&$Z@L$
M#_*`>]OI`*M!ZMAA`9$F1M[I`$5/ZMA@F0@4ZPH$0.I)$$7K"P7-Z19%#IS=
MZ0RKID;=Z19%BNH&"A3K#@0-]1Y^5D9%\0`%HD9/ZD@4`)0:ZP8$W>D`9T7Q
M``4&0Q3K!@I/ZH)T1?$`"YT'S>D.JYBK3_``"T7JD@5?1E9&T^D`(T_P``I/
M\``+S>D`JT7J`0MY`0&11.H%"@_RY&'1Z0`!W>D"18`8S>D,JUE!A.H*!`&;
MC$;=Z1`20^K68P&384#R#D+J1Q)/ZID##$8$F4`83/$``0`9BT9/ZD81`)%+
M\0`!W>D`111#$.L$"T_JB'!!\0`,3^J)<4'JF`%/\``)3_``",WI`(E!Z@,)
M0.H!"%Q&94;-Z1!%`"5!1DI&:P'=Z0R)`9.:JXCJ`0C-Z002T^D``0_R2&/3
MZ0`C@!A900&;BT;=Z0X20^K48P&3@>H(`>(.0NI%$KL(B$8"F4`82_$``1#K
M"`"+1D_J1!$`D4OQ``'=Z0")3_``"4CJ`@@0ZP@*3^J&<$'Q``NY!T'JE@'0
M1LWI#JM`Z@$*0>H#"P`F4D9/ZDD16T;=Z02KS>D"(YRKBNH""@`GS>D`9P&1
M5D8/\KQ2TND`$M/I`*L!FQKK`0I+ZP(+W>D0$D/JV&,!DW%`3^K88D+J21*K
M"`Y&#)D:ZP$`2_$``8`9BT9/ZD@1`)%+\0`!W>D`9Q9#$.L&"D_JA'!!\0`+
MJ0=!ZI0!S>D0JP`D3_``"P`ES>D`14#J`01?1D'J`P5[`:-&`9/=Z0(TK$;>
MZ0`!5D:#Z@L#S>D,O`_R*%S<Z0"\#?4@?AQ&`9L0ZPL`0>L,`4/JVF,!DT_J
MF0.,1MWI#A+R#F%`0NI'$@Q&!)E`&$SQ``$`&8M&3^I&$0"12_$``=WI`$44
M0Q#K!`M/ZHAP0?$`#$_JB7%!ZI@!7$9!Z@,)0.H!"&5&S>D.14%&2D;=Z0R)
M`"7-Z002:P$/\JA+V^D`JXCJ`0C>Z0`!0^K48P&3NP@0ZPH`#?4D?D'K"P&+
M1MWI$!+B#H'J"`%"ZD42B$8"F4`82_$``1#K"`"+1D_J1!$`D4OQ``'=Z0")
M3_``"4CJ`@@0ZP@*3^J&<$'Q``NY!T'JE@'01LWI$*M`Z@$*0>H#"P`F4D9/
MZDD16T;=Z02KS>D"(Z*KBNH""@`GS>D`9P&15D8/\@Q"TND`$M/I`*L!FQKK
M`0I+ZP(+W>D.$D/JV&,!DW%`3^K88D+J21*K"`Y&#)D:ZP$`2_$``8`9BT9/
MZD@1`)%+\0`!W>D`9Q9#$.L&"D_JA'!!\0`+J0=!ZI0!S>D.JP`D3_``"P`E
MS>D`14#J`01?1D'J`P5[`:-&`9/=Z0(TK$;>Z0`!5D:#Z@L#S>D,O`WU)GX<
M1MVCT^D`(X`864$!FXQ&W>D0$D/JVF,!DV%`\@Y"ZD<23^J9`PQ&!)E`&$SQ
M``$`&8M&3^I&$0"12_$``=WI`$440Q#K!`M/ZHAP0?$`#$_JB7%<1D'JF`%E
M1LWI$$4`)0_R%#O;Z0"K3_``"$_P``G-Z0")0.H!"$'J`PEI`0&10D;>Z0`!
M2T;=Z0R)#?4J?A#K"@#-Z00C0>L+`8CJ`@@!FXM&W>D.$D/JU&,!DX'J"`'B
M#D+J11*["(A&`IE`&$OQ``$0ZP@`BT9/ZD01`)%+\0`!W>D`B4_P``E(Z@((
M$.L("D_JAG!!\0`+N0=!ZI8!T$;-Z0ZK0>H#"T#J`0I/ZDD36D8`)E%&W>D$
MJP`GS>D`9XKJ`0H!DZBKS>D"$E9&T^D`JY.CT^D`(QKK`@K=Z1`22^L#"P&;
M<4!/ZMAB0^K88P&3#D8,F4+J21*K"!KK`0!+\0`!@!F+1D_J2!$`D4OQ``'=
MZ0!G%D,0ZP8*3^J$<$'Q``NI!T'JE`'-Z1"K`"1/\``+`"7-Z0!%0.H!!%]&
M0>H#!7L!HT8!D]WI`C2L1M[I``%61H/J"P/-Z0R\#?4L?AQ&;Z/3Z0`C@!A9
M00&;C$;=Z0X20^K:8P&384#R#D+J1Q)/ZID##$8$F4`83/$``0`9BT9/ZD81
M`)%+\0`!W>D`111#$.L$"T_JB'!!\0`,3^J)<5Q&0>J8`65&S>D.10`E#_)<
M&]OI`*M/\``(3_``"<WI`(E`Z@$(0>H#"6D!`9%"1M[I``%+1MWI#(D-]3!^
M$.L*`,WI!"-!ZPL!B.H""`&;BT;=Z1`20^K48P&3@>H(`>(.0NI%$KL(B$8"
MF4`82_$``1#K"`"+1D_J1!$`D4OQ``'=Z0")3_``"4CJ`@@0ZP@*3^J&<$'Q
M``NY!T'JE@'01LWI$*M!Z@,+0.H!"D_J21-:1@`F44;=Z02K`"?-Z0!GBNH!
M"@&3KJO-Z0(25D;3Z0"K):/3Z0`C&NL""MWI#A)+ZP,+`9MQ0$_JV&)#ZMAC
M`9,.1@R90NI)$JL(&NL!`$OQ``&`&8M&3^I($0"12_$``=WI`&<60Q#K!@I/
MZH1P0?$`"ZD'0>J4`<WI#JL`)$_P``L`)<WI`$5`Z@$$7T9!Z@,%>P&C1@&3
MW>D"-*Q&S>D,O%9&@^H+`][I``$(X`"_W+P;CP````#6P6+*``````WU,GX<
M1MJCT^D`(X`864$!FXQ&W>D0$D/JVF,!DV%`\@Y"ZD<23^J9`PQ&!)E`&$SQ
M``$`&8M&3^I&$0"12_$``=WI`$440Q#K!`M/ZHAP0?$`#$_JB7%<1D'JF`%E
M1LWI$$4`)0_R"#O;Z0"K3_``"$_P``G-Z0")0.H!"$'J`PEI`0&10D;>Z0`!
M2T;=Z0R)#?4V?A#K"@#-Z00C0>L+`8CJ`@@!FXM&W>D.$D/JU&,!DX'J"`'B
M#D+J11*["(A&`IE`&$OQ``$0ZP@`BT9/ZD01`)%+\0`!W>D`B4_P``E(Z@((
M$.L("D_JAG!!\0`+N0=!ZI8!T$;-Z0ZK0>H#"T#J`0I/ZDD36D8`)E%&W>D$
MJP`GS>D`9XKJ`0H!D[2KS>D"$E9&T^D`JY"CT^D`(QKK`@K=Z1`22^L#"P&;
M<4!/ZMAB0^K88P&3#D8,F4+J21*K"!KK`0!+\0`!@!F+1D_J2!$`D4OQ``'=
MZ0!G%D,0ZP8*3^J$<$'Q``NI!\WI$*M/\``+7T9!ZI0!0>H##``D>P$`)<WI
M`$5`Z@$+`9-61MWI`C3-Z0R\WND`$H/J"P,/\K@;V^D`JPWU.'X<1@&;$>L*
M`4+K"P)#ZM9CBD8!DY-&W>D.$O(.3^J9`V%`0NI'$@Q&!)D:ZP$`2_$``0`9
MBT9/ZD81`)%+\0`!W>D`10`E%$,0ZP0+3^J(<$'Q``Q/ZHEQ0>J8`5Q&0>H#
M"4#J`0C-Z0!%049*1MWI#(E/ZI<)WND`-`WU.G[=Z1!%B.H!",WI!!*$Z@@$
M2*+2Z0`2S>D.O$_JAWN@1@"<6QA+ZI8+2^H)!>`.`IRI1AH9`9P2ZP@"`"-`
MZD00`)Q/ZD0:0.H*`$_JAGI*Z@L$W>D$JQ(8WND`9Z!&B^H%"UP!BNH("D3J
MTF[=Z0Y%S>D0B=!&V48/\K@+V^D`JX3J"`2%Z@D%S>D.11KK!@H,G'!&S?@,
MX``C&NL$!E0!`I1/\``)#IPV&=WI`D4$0R!&`)PV&$_JE`K=Z0!%W>D&`0`A
MW?CTPD_JA'@:G(`92NJ%>MWI"E9(Z@H(Q.D``=WI%`$;F8`8T?@`X`)&$)EM
M&`29+D;=Z1)%`"5D&-WI"`$`(1#K"`"P1AJ>]$7&Z0(CQND&B<;I"$7&Z00!
M`]$-]3]]O>CPC_SW$NT`OZ_S`(#6P6+*```````H/-`MZ?A#2_(P$\#R`@/3
M^`"0N?$`#R[0!7@`+1B_/2T4OP$E`"45T=GX`$!\L8!&#T9.1BI&048@1OSW
M_NT0N6-=/2L/T%;X!$\`+/+1($:]Z/B#!485^`$_`"L8OSTK^=$M&N#GINL)
M!F@<($2V$#Y@O>CX@TA&O>CX@W!'<+5+\C@5P/("!8*P2_(P%L#R`@8K:`1&
M`9-I1B!&__>O_Z"Q`)@Q:`'K@`-::$'X("``*O'0!#-::$/X!"L`*OK1:48@
M1O_WF_\`*.K1`9HK:)I"`=$"L'"]_/><[`"_+>GP3TOR.!4+>,#R`@4,1H6P
M/2LJ:`B_`30&1B!&`Y+\]P+M`JD'1C!&__=Y_X!&`"A4T/SW^.R'0D?9`IM+
M\C`9P/(""4_J@P@P>``H&+\]*!2_`2``(`?0,$80^`$_`"L8OSTK^=&`&P(W
MV?@`H#A$_/>V[$KX"```*&[0V?@`('$<`I@S>%+X(``]*QB_`"L#<`G00AP1
M^`$[$$8`*QB_/2L"^`$[]M$"1CTC`W`4^`$[`O@!/P`K^=$`(`.:*VB:0DW1
M!;"]Z/"/"/'_,!3X`3L`^`$_`"OYT>[G2_(P&<#R`@G9^`"PV_@`,).S6T8`
MX%!&4_@$+P#Q`0H`*OC1`S"``$OR8!+`\@("$VB#L0%&6$;\]R+LR?@``.BQ
M3^J*"`KQ`0,`(D#X(R#-^`B@BN<!(Q-@_/=2[`&0:+%/ZHH(649"1OSWN.L!
MFQA&R?@`,.;GFD8((-3G3_#_,*WG_/?HZP"_+>GP0TOR.!7`\@(%G[`K:!V3
M$+$#>`=&,[D=FBMHFD)3T1^PO>CP@_SW&NP&1@`H\]!&\FP(P/(!"#!&_/?"
M[("SPWPN*S30`/$3!#A&_/<X[(%&($;\]S3L2$0",/SW#.Q#1D_P_S(!(0&4
M`)>!1OSW/NQ)1@*J`R#\][;L`3!(1@70!IL#]'!#L_6`3QG0_/>JZTA&_/=D
MZS!&_/>2[``HSM$P1OSWONPX1OSW=NNSYP-]`"O`T"XKQ=%#?0`KN]#!Y__W
MG/_DY_SW@.L`OSBU2_)`%,#R`@0%1B!H_/>H["E&`/6D<@,@_/>6[`BQ`"`X
MO2!H_/><[-#X6#$#]'!#L_6`3PG0(&C\]Y+LT/A8,0/T<$.S]2!/Z=$H1@(A
M_/<X[+#Z@/!`"3B]\+5+\C@4K?6`7<#R`@2#L`9&(V@-]8!5!#4/1D;R=``!
MJ<#R`0!`]O]R*V#\]U[K`"@CW44>`:M;7>NQ!48J1B\A`:C\]PKLP+%+\D`3
MP/("`QAH_/=6["M&`:HQ1OSW(NP-]8!3!#,::"-HFD(1T0WU@%T#L/"]`"W@
MT4OR0!/`\@(#&&C\]S[L.D8Q1OSW*.OFY_SW!.M+\D`3P/("`Q"U&&C\]R[L
M1?;P<T'R,%)&\H0!P/(!`\#R`0+`\@$!O>@00/SWDKL0M4OR0!3`\@($@K`@
M:/SW%NS_]]W_(&C\]Q#L`"%&\GPS`9'`\@$#1?:90@"3P/(!`D;RH`'`\@$!
M_/>FZP*P$+T`OW"U2_(X%*WU`%W`\@($AK`C:`WU`%(4,A-@_/<JZT;RQ`)&
M\K@#P/(!`L#R`0,!D@$A0?(!`@"0`ZC\]S[K`"@BVPWU@%$#J$_T@%(0,?SW
MR.H%'AC;:!S\]_+J!D:HL0WU@%$J1A`Q_/=JZC!&`"-S50WU`%,4,QIH(VB:
M0@;1#?4`70:P<+T`(/+G\>?\]X+J`+__][2_+>GP3TOR.!:M]8%=P/("!H&P
M!$8S:`WU@%(<,@]&1O+,``:IP/(!`!-@__==_2\A!48@1OSWZ.J@L4;RV``A
M1L#R`0#_]\#]($8-]8!3'#,::#-HFD)`\).`#?6!70&PO>CPCR!&_/?$ZD;R
MZ`'`\@$!@D8X1OSW+.N!1@`HW-!&\L@'1O+L",#R`0?`\@$(1O+T`\#R`0,%
MDYGX`#``*PB_N48ML4E&*$;\]]3I`"A*T$A&_/><ZD$>">L!`QGX`1`O*0C1
M3_``#H/X`.`!.!/X`1TO*?C0"O$!`QA$L/6`7ZK:!9M+\D`;P/(""T_T@%(!
M(0*4`9,'J$-&S?@`D/SWCNK;^```_/<JZP>I`/6D<@,@_/<`ZU"YV_@``/SW
M(.O0^%@Q`_1P0[/U`$\6T$;RZ`$`(,#R`0'\]\KJ@4:Y\0`/J=%XYT;RZ`'`
M\@$!_/>^ZH%&N?$`#Y[1;><!(0>H_/>PZ@`HXM$'J4;RV`#`\@$`__<H_0>H
M_/=@ZF3G_/>\Z0-X.[%"'"\K"+\01A+X`3L`*_C1<$<`OSBU>+,%>`1&9;/\
M]R3J`3@B&)1"#-(C7"\K+-%3'@+@$7@O*2?1HT(:1@/Q_S/WT91"+-`!.@/@
M$7@O*031&D:40@+Q_S/WTQ(;DQRS]8!?#]@!,B%&3_2`4Q)(_/=ZZ1!(.+T"
M(/SWTND0L2XB`H`XO0`@.+U3'@+@$7@O*=G0G$(:1@/Q_S/WTY1"TM$O+>C0
M1O+T`,#R`0"]Z#A`_/?]N0"_9+$"`/"UC;!?30*L2_(X%L#R`@8/S3=H#\0/
MS0N7+6@/Q$;R^`#`\@$`)8#_]WS\1O($$,#R`0#_]W;\1O(,$,#R`0#_]W#\
M1O(8$,#R`0#_]VK\1O(@$,#R`0#_]V3\1O(P$,#R`0#_]U[\1O+,`,#R`0#_
M]UC\1O(\$,#R`0#_]U+\1O)($,#R`0#_]TS\1O)4$,#R`0#_]T;\1O+8`,#R
M`0#_]T#\1O)@$,#R`0#_]SK\1O)L$,#R`0#_]S3\1O)X$`&IP/(!`/_W[?LP
ML0%&1O)($,#R`0#_]U7\1O*,$`&IP/(!`/_WWOLPL0%&1O*@$,#R`0#_]T;\
M1O*L$`&IP/(!`/_WS_NPL0%&1O+,`,#R`0#_]S?\1O+<$4;R(!#`\@$!P/(!
M`/_W+?P+FC-HFD(ET0VP\+U&\KP0`:G`\@$`__>P^SBQ`49&\CP0P/(!`/_W
M&/S?YT;RT!$*(L#R`0$-\1D`_/>\Z0`HU-%&\CP0#?$C`<#R`0#_]P3\R^?\
M]YSH`+_\7P$`,+5+\C@4P/("!$OR)!7`\@(%@[`C:"AH`9-#'`70`9HC:)I"
M$M$#L#"]1O(\$&E&P/(!`/_W<OLPL0!X,"@8OP`H%+\!(``@*&#HY_SW<.@(
MM?SW+.C\]Q[H`+$`:`B]+>GP3P=&+$R/L`:M2_(X&,#R`@@/S-CX`&`/Q93H
M!P`&G`V6A>@'``RS1O+H"D;R[`G`\@$*P/(!"0:M!N`Y1OOW[._8L57X!$^$
ML06I($;_]S3[!D80L0-X`"OOT2!&.4;_]YO[5?@$3P`L[M$-FMCX`#":0AW1
M#["]Z/"/.$;\]Z#H@T8P1OSWG.A81`(P_/=TZ`*62T;-^`2@3_#_,@"7`2&#
M1OSWINA91B!&__=U^\CG_/<,Z"!@`0`MZ?!/!T:%3*WU`4V1L$OR.!,$\0P.
M$JZ4Z`<`P/("`PB3&*TD-`WQ5`B&Z`<`ON@/``_%GN@#``B;A>@#`)3H!P`-
M]0%$&V@\-(CH!P!&\LP`$:G`\@$`(V#_]]'Z(+$#>`1&`"M`\(J!__=C_P5&
M`"A1T"A&_/=(Z$```3#\]R#H*WA&\N@9P/(!"8!&!$9CL0"3($9+1D_P_S(!
M(0(T_/=*Z!7X`3\`*_+1&)@8K!BY%.!4^`0/B+$1J?_WH/H%1@`H]M`#>``K
M\]#_]R3\`"COT"A&_/<^Z(%&8+L2G$2S(W@!)3.Y).!6^"5`#+,C>`$U\[$@
M1O_W#OP`*/30($;\]RCH`"COT(%&%.#\]R+H`"A`\#&!6/@$"P`H`/`T@1&I
M__=L^@`H]=`#>``K\M#LYT_P``E(1D;R]`O[]^3OP/(!"P1&0$;[]][O($0`
M\@1$($;[][3O`2'-^`R`1O+\$LWX`)#`\@$"S?@$L$;R\!,"DL#R`0-/\/\R
M@D;[]]KO4$9/].!Q^_?R[P$P+-!+\D`5P/("!2AH_/=LZ%%&`/6D<@,@_/=:
MZ``H-]!+\D@1P/("`3MH1O*$(@AHP/(!`LWX`*`!(?OW]N\`(`WU`4,\,QIH
M")L;:)I"0/"8@@WU`4T1L+WH\(_[]Y[O`6@1*<W02_)($,#R`@`[:$;R!"(`
M:,#R`0(!D0$AS?@`H/OWTN\`(-KG`+\\8`$`*&C\]RKHT/A8,0/T<$.S]8!/
MO=$H:/SW(.C0^&!A^_>H[H9"M-$H:/SW%NC0^%@QP_,(`[/UX'^JT2!&^_<P
M[Q&I!$9&\M`PP/(!`/_WR/D`*`#PD(`]:/OW;.\!1BA&__=*_`5&`"@`\(6`
M*$;[]SSO`R@&1A'=!#A&\D`A*$3`\@$!^_=B[D"Y!"X`\-2!+D06^`4\+RL`
M\,Z!__<2_C"Y`48H1OOW]NX)D``H9-%&\MP11O(\$,#R`0'`\@$`__?^^4;R
M?#?[]P+OP/(!!\WX!+!&\F`C`Y?`\@$#S?@`H$_P_S(!(4;R<"BY1L#R`0@`
M)E=&`I`@1OOW#N\4X/OW!.\#:!$K%]'[]^+N`3;-^!"0*D8#ED-&S?@$L`$A
M`)<"D"!&^_?X[D_TX'$@1OOW#N]#'`5&XM"Z1E!&^_<D[B%&1O+,`,#R`0#_
M][CY($;_]^?]($8JYP5&>N;_]^']($;[]^;N(N=&\N`5#2#`\@$%<^8]:'CG
M3_#_,V_P$0(")0"5^_=T[D^I!B()F/OWZ.V=^#PQ([F=^#TQ0RL`\&^!`"4`
M(@`C`)4)F/OW8.[1H='I``'1H]/I`",\E<WI(`$LJ0J1SZ'1Z0`!S>DB(\^C
MT^D`(\WI)`'.H='I``'-Z28C`"(`(PN4S>DH(\WI*B/-Z1X!S?@PH,WX-+!/
M]`!"3ZD)F/OWK.T$'G;=W>DH`4_JQ`H`)R)&&NL`!H]""+^&0D_JY'-AT]WI
M*HE5#P:5!ID\G4'JPP%;#P:1!Y/=Z08!S>DH9Q#K"`!!ZPD!S>DJ`0`M2-#%
M\4`'"ING0D^I`^L%`*B_)T8Z1OOWF.T\FSM$/)-`*\'13ZL>J.0;'T3\]SCX
M/RPGW4`\!_%`#$_JE!D)\0((!^N(&*SQ0`4-\;`.*&@0-57X#!QV1E7X""P.
M\1`.5?@$/&5%#\;QT1ZH_/<8^`7Q0`S$1>;1"?$!`Z3KB10'ZX,7.49((R)&
M"IC[][+M/)2)YT^OR^?=Z2H!$/$!"$'Q``F8YPNL"9@LKY3H$`S[]Y3N@"$H
MG2J>Q?/%`E,<."NY5`#SHH#X&,/Q.`(`(?OW&.X>J"H.,PZ-^.M@C?CO4`WU
MB'F-^.@P,PR-^.P@-@J-^.DP*PR-^.I@+0J-^.TP1O+H&(WX[E#[]\G_(IH-
M\@\5'IC`\@$(()D_KXWX!R$&#`,.C?C_```*C?@#$8WX_@`(#HWX``$(#`D*
MC?@!`8WX`A$0"A$.C?@$$1$,)IJ-^`41))F-^/U@3D:-^`8!C?@+$0@.C?@/
M(8WX"`$(#(WX_#`)"HWX"0&-^`H1$0Z-^`P1$0P2"HWX#1&-^`XA`>`7^`$_
M`),P1D-&3_#_,@$A`C;[]XSMO4+RT<WX")``(,WX!+!&\GPRS?@`H,#R`0)&
M\E`C`Y+`\@$#B?@H`$_P_S(!(2!&^_=R[8'F?F@`+C_T+JXP1OOW4NT#*'_V
M**X$.$;R2"$P1,#R`0'[]WCL`"@(OS5&&^;#\4`"^!@`(?OW=NT>J/OW0?\X
M1C@B`"'[]V[M5.>=^#XQ02M_](RNG?@_,4,K?_2'KIWX0#%(*W_T@JZ=^$$Q
M12M_]'VN`)5/\/\S"9UO\#D"*$;[]]KL3ZDH1BDB^_=0[$^KS?@$L$;R?#("
MD\#R`0+-^`"@1O)0(P.2P/(!`T_P_S(!(2!&^_<4[23F^_>`[`"_B:O-[P``
M``#^W+J8`````'94,A``````\.'2PP`````!(T5G`````"WI\$]+\C@3A;#`
M\@(#2_)`%\#R`@<!DQMH.&@#D_OWC.T!(P*I@/AE,$;R(!#`\@$`_O=%_QBQ
M`W@Q*P#PP8#_]^SZ.&A,\E@F^_=V[4;RV"$+(\#R`0$!(L#R`@;[]YSL`"@^
MT%;X]#P":0$KTO@8D#?=3_2`:@`EP/(@"@$D(.`!:%;X\`R+:%#X)(`*Z@,#
ML_6`;PB_"6D)T#AH^_=,[=OX`!`"(P`B^_=&[`%&0$;[][SK5OCT/("Y`30!
M-:-"#-TX:/OW..T`(RI&24;[]_#L@T8`*-/15OCT/%H>JD)?T#AH^_<H[4;R
MX"$#(\#R`0$!(OOW4.P$1H"Q.&C[]QKM(VE&\N0BP/(!`AEH^_<`["-I&VB;
M:%L"`/&D@#AH^_<*[4;R["$#(\#R`0$!(OOW,NP$1I"Q1O+8``*IP/(!`/[W
MO/X%1CAH`"T`\(&`^_?R["-I*D89:/OWVNLX:/OWZNP`(P*I@/AE,$;RS`#`
M\@$`_O>C_@5&1OCL#""S3_3@<?OW5.Q#'!$H&+\!*WG8`9L#FAMHFD)RT06P
MO>CPCP$KG=T!)#AH`33[]\3L24;[]U[K5OCT/*-"]-R0YT-X`"L_]#VO.>=6
M^/`,__=V^T;X[`P`*$W0(VE/](!BP/(@`AEHBV@30+/U@&\(OPAI"-`X:/OW
MGNPA:2I&`B,):/OWF.M6^/!<*4;[]S[K(VE/](!BP/(@`BUH&6B+:!-`L_6`
M;PB_"FD&1@G0.&C[]X+L(6D`(@(C"6C[]WSK`D9&\A0P,T8I1L#R`0#[]]CK
M^_=P[%;X\"PC:1%H&&C^]^?_>^<X:/OW9NPC:1EH^_?VZU/G1O+P(,#R`0#[
M]\#K^_<FZU;X\!P#1BI&1O(\,,#R`0`):/OWM.L`OSBU!4;_]V;Y`W@$1CNQ
M0APO*PB_%$82^`$[`"OXT?_W<?H`+1B_`"@*T"MX0[%&\OP1($;`\@$!^_>B
MZH1"`-`XO2A&O>@X0/[W#K\%2Q"T>T0%3!M9`[$;:%WX!$O[]^^Z`+]T4`$`
M&`$``"WI^$,'1@M.B$8+39%&?D3[]W#J?41V&[80"=``)`$T5?@$.TI&048X
M1IA'M$+VT;WH^(-"3P$`.$\!`'!'`+\(0"WI"("]Z`$``@!P97)L>'-I+F,`
M``!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(`````"P8P$`P&,!
M`,AC`0#08P$`V&,!`.QC`0``````J&,!`,A@`0``````H&$!`*1A`0"<8P$`
MT&`!`*1C`0``````B&,!`)!C`0``````)7,O)7,````O<')O8R]S96QF+V5X
M90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2
M.CI"3T]4`````"]P<F]C+R5I+R5S`&5X90`N````4$%27U1%35``````4$%2
M7U!23T=.04U%`````#H````E<R5S)7,``"\```!015),-4Q)0@````!015),
M3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]3
M4$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!
M4E]!4D=#`````%!!4E]!4D=67S```%!!4E]'3$]"04Q?1$5"54<`````4$%2
M7T=,3T)!3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``
M4$%27T=,3T)!3%]#3$5!3@````!005)?0TQ%04X]```Q````4UE35$5-```E
M,#)X`````"5S)7,E<R5S`````'!A<BT`````)7,Z(&-R96%T:6]N(&]F('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``<&%R
M;``````N<&%R`````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````
M)7,E<W1E;7`M)74M)74E<P`````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R
M(&]P97)A=&EO;BD*``!!4D=6`````!@```!P97)L`````#````!5;F%B;&4@
M=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@97AE8W5T:6]N(&]F
M("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M```M90``+2T``%5315(`````55-%4DY!344`````5$5-4$1)4@!435``+W1M
M<`````!,1%],24)205)97U!!5$@`3$E"4$%42`!,24)205)97U!!5$@`````
M1%E,1%],24)205)97U!!5$@```!32$Q)0E]0051(``!E=F%L("=E>&5C("]U
M<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N
M;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D
M<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.
M5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER
M(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ
M<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD
M.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@
M)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP
M("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI4
M96UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.
M3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL
M92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@
M7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]
M8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@
M(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T
M;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T
M;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@
M<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M
M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D
M969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI
M=%]E;G8H*3L*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6
M>U!!4E]!4D=67S!]("D@>PI`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D
M7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PHD,"`]("1%3E9[4$%2
M7T%21U9?,'T["GT*96QS92!["F9O<B`H:V5Y<R`E14Y6*2!["F1E;&5T92`D
M14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["GT*?0IM>2`D<75I970@/2`A)$5.
M5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H
M)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@
M*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G
M*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG
M(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D[
M"FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]7
M05).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@
M;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P
M<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL
M92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS
M965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N
M("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F
M+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z
M("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H
M)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F
M9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E
M="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D
M:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U
M9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL
M(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I
M("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B
M*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP
M86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U
M;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*
M;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ
M*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X
M="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@*"1O=70L("1F:6QE
M;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["FEF("@D;W5T*2!["F)I
M;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&)U9CL*8VQO<V4@)&]U=#L*8VAM
M;V0@,#<U-2P@)&9I;&5N86UE.PI]"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE
M(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I
M('L*;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E
M>'0B.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*;W!E;B!M>2`D;W5T
M+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&]U="D["G!R
M:6YT("1O=70@)&)U9CL*8VQO<V4@)&]U=#L*?0IE;'-E('L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F
M=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]
M/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@
M0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@
M9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y
M.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@
M+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E
M<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R
M;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE
M(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z
M.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I
M92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F
M?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`H
M)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC
M<F-]*3L*:68@*"1O=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D
M9FEL96YA;64M/GMB=69].PIC;&]S92`D;W5T.PI]"F]P96X@;7D@)&9H+"`G
M/"<L("1N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H
M.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M
M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER
M92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X
M<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O
M<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I
M;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE
M;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L
M<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U
M<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE
M;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S
M=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY
M("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E
M("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B
M92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[
M4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G
M+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W
M*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A
M;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%2
M1U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*
M)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C
M(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@
M*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N
M*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN
M8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]
M"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]
M"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E
M<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G
M*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q
M=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@
M(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]
M"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF
M="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE
M=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z
M.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*
M=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*
M<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@
M)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A
M<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P
M96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A
M<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I
M.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&
M:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@
M/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S
M*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T
M82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD
M+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*
M;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D
M92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\
M4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY
M("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4
M*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#
M*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E
M9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?
M1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.
M5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI
M+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E
M86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV
M>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O
M7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N
M(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"([
M"B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G
M("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M
M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR
M97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@
M/2!S;W)T('L*;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0I](&=R97`@>PHA
M+T)31%!!3B\*?2!G<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N
M9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*
M+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y
M<R`E.CH["B1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["FUY("1L:6)?
M97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*
M9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE
M*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*
M96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R
M+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE
M879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E
M9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@
M=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK
M*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB
M7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D
M9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@
M)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M
M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE
M(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT
M96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE
M(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L
M(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P
M.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL
M("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54
M;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T
M<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY
M("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ
M340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z
M.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N
M,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL
M92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD
M(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M
M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@
M)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M
M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE
M7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F
M:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R
M*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H
M;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D
M("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z
M.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF
M9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ
M3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D
M>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6
M>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I
M;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE
M>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]
M("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@
M/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO
M*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*
M?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I
M;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA
M;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N
M8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R
M7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE
M(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M
M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.
M86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D
M;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E
M<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E
M<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@
M=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U
M=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN
M,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R
M97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER
M92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!0
M97)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I
M<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@
M>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@
M*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`]
M(&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F
M5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G
M:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@
M/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O
M7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A
M<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O
M9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U
M9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L
M(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*
M96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@
M1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E
M<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*
M:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q
M("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H
M)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD
M<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H
M*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE
M("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@
M,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%
M3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92![
M"FUY("@D97AT+"`D8W)C*2`]($!?.PIM>2`H)&9H+"`D9FEL96YA;64I.PHD
M9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*:68@*"1%3E9[4$%2
M7T-,14%.?2D@>PIU;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*
M<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PI]"F5L<V4@>PIR971U<FX@*'5N
M9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PI]"F]P96X@)&9H
M+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T
M=7)N*"1F:"P@)&9I;&5N86UE*3L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF
M("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/
M1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA
M;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G
M;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B
M<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N
M(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*
M?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M
M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D
M:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]
M*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q
M("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<
M120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M
M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I
M>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'
M3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ
M9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z
M.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^
M(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[
M7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS
M=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]
M*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,
M25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)5
M1R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.
M5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%
M0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D
M<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!
M3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@
M>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H
M(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@
M+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@
M)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*
M96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I
M<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF
M:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET
M96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X
M<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.
M0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID
M:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA
M;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D
M<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD
M.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z
M.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%
M4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``Y'?_?P$`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$T:`0`U&@$```````$````!`````0```-,!```!````
M(@(```$```!U`P``#````)@4`0`-````Y%\!`!D```#TK@(`&P````0````:
M````^*X"`!P````$````]?[_;[0!`0`%````)`P!``8```!D!0$`"@```/$$
M```+````$````!4``````````P````"P`@`"````$`(``!0````1````%P``
M`(@2`0`1````4!(!`!(````X````$P````@```#^__]O\!$!`/___V\#````
M\/__;Q81`0``````````````````````````````````````````````````
M````````````````KP(```````````"D%`$`I!0!`*04`0"D%`$`I!0!`*04
M`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!
M`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`
MI!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D
M%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04
M`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!
M`*04`0"D%`$`I!0!`*04`0``````(+$"````````````______AC`0!'0T,Z
M("A58G5N='4O3&EN87)O(#4N,RXQ+3$T=6)U;G1U,BD@-2XS+C$@,C`Q-C`T
M,3,`03(```!A96%B:0`!*`````4W+4$`!@H'00@!"0(*!!($$P$4`14!%P,8
M`1D!&@(<`2(!`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO
M=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N
M=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI
M;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%232YE>&ED>``N96A?9G)A;64`
M+FEN:71?87)R87D`+F9I;FE?87)R87D`+FIC<@`N9'EN86UI8P`N9V]T`"YD
M871A`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````````````````
M```````````````````````````````````````````+`````0````(```!4
M`0$`5`$``!D```````````````$`````````$P````<````"````<`$!`'`!
M```@```````````````$`````````"$````'`````@```)`!`0"0`0``)```
M````````````!``````````T````]O__;P(```"T`0$`M`$``+`#```%````
M``````0````$````/@````L````"````9`4!`&0%``#`!@``!@````$````$
M````$````$8````#`````@```"0,`0`D#```\00``````````````0``````
M``!.````____;P(````6$0$`%A$``-@````%``````````(````"````6P``
M`/[__V\"````\!$!`/`1``!@````!@````,````$`````````&H````)````
M`@```%`2`0!0$@``.`````4`````````!`````@```!S````"0```$(```"(
M$@$`B!(``!`"```%````%@````0````(````?`````$````&````F!0!`)@4
M```,```````````````$`````````'<````!````!@```*04`0"D%```.`,`
M````````````!`````0```""`````0````8```#@%P$`X!<```1(````````
M``````@`````````B`````$````&````Y%\!`.1?```(```````````````$
M`````````(X````!`````@```.Q?`0#L7P``P$$`````````````!```````
M``"6`````0``<((```"LH0$`K*$```@````-``````````0`````````H0``
M``$````"````M*$!`+2A```$```````````````$`````````*L````.````
M`P```/2N`@#TK@``!```````````````!`````````"W````#P````,```#X
MK@(`^*X```0```````````````0`````````PP````$````#````_*X"`/RN
M```$```````````````$`````````,@````&`````P````"O`@``KP````$`
M``8`````````!`````@```#1`````0````,`````L`(``+```!P!````````
M``````0````$````U@````$````#````'+$"`!RQ```0```````````````$
M`````````-P````(`````P```#"Q`@`LL0``1!``````````````"```````
M``#A`````0```#``````````++$``#0```````````````$````!````Z@``
M``,``'```````````&"Q```S```````````````!``````````$````#````
@``````````"3L0``^@```````````````0``````````
